@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2009 Zope Corporation and Contributors.
+# Copyright (c) 2009 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -18,14 +18,13 @@ from zope.publisher.interfaces.browser import IBrowserRequest
 
 from grokcore.view.interfaces import IGrokView
 
-from Acquisition import aq_parent, aq_inner
+from Acquisition import aq_inner
 
 from zope import component
 from grokcore import component as grok
 
 
 class ViewAbsoluteURL(absoluteurl.AbsoluteURL, grok.MultiAdapter):
-
     grok.adapts(IGrokView, IBrowserRequest)
     grok.provides(IAbsoluteURL)
 
